/* ***************************************************************************
   *                                                                         *
   *   Kindermann                                   WPK-Produktentwicklung   *
   *                                                Schuljahr 2016/17        *
   *                          SonoffControl-01                               *
   *                                                                         *
   *                                                                         *
   ***************************************************************************/



#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <WiFiManager.h>

//for LED status
#include <Ticker.h>
Ticker ticker;

#define TRIGGER_PIN 0

ESP8266WebServer server(80);

String webPage1 = "", webPage2 = "";

int gpio13Led = 13;
int gpio14Led = 14;
int gpio12Relay = 12;
unsigned long ledstatus = 0;

void tick()
{
  //toggle state
  int state = digitalRead(gpio13Led);  // get the current state of GPIO1 pin
  digitalWrite(gpio13Led, !state);     // set pin to the opposite state
}

//gets called when WiFiManager enters configuration mode
void configModeCallback (WiFiManager *myWiFiManager) {
   //entered config mode, make led toggle faster
  ticker.attach(0.2, tick);
}

void setup(void){
   
  webPage1 += "<!DOCTYPE html>\r\n";
  webPage1 += "<HEAD>\r\n";
  webPage1 += "<META content=\"text/html; ";
  webPage1 += "charset=\"ISO-8859-1\"; ";
  webPage1 += "http-equiv=\"content-type\">\r\n";
  webPage1 += "<TITLE>SonoffConrol</TITLE>\r\n";
  webPage1 += "</HEAD>\r\n";
  webPage1 += "<FONT face=Verdana>\r\n";
  webPage1 += "<H1>SonoffControl</H1>\r\n";
  webPage1 += "LED-Status: ";
  
  webPage2 += " <br>\r\n<br>\r\n";
  webPage2 += "<button style=height:25px;width:60px onclick=location.href=\"on\" ";
  webPage2 += "type=button>EIN</button>&nbsp;LED einschalten<br><br>\r\n";
  webPage2 += "<button style=height:25px;width:60px onclick=location.href=\"off\" ";
  webPage2 += "type=button>AUS</button>&nbsp;LED ausschalten<br><br>\r\n";
    
  webPage2 += "<BODY>\r\n";
  webPage2 += "<FONT SIZE=-2>(c) Dietrich Kindermann 2017<br></BODY></HTML>";
  
    
  // preparing GPIOs
  pinMode(gpio13Led, OUTPUT);
  digitalWrite(gpio13Led, HIGH);

  pinMode(gpio14Led, OUTPUT);
  digitalWrite(gpio14Led, HIGH);
  
  pinMode(gpio12Relay, OUTPUT);
  digitalWrite(gpio12Relay, LOW);
 
  // start ticker with 0.5 because we start in AP mode and try to connect
  ticker.attach(0.6, tick);

  //WiFiManager
  WiFiManager wifiManager;
  
   // delay 2 sec for reset
   delay(2000);
  
  if ( digitalRead(TRIGGER_PIN) == LOW ) {
    //reset settings
    wifiManager.resetSettings();
  }

  WiFi.hostname("sonoffcontrol");
  
  //set callback that gets called when connecting to previous WiFi fails, and enters Access Point mode
  wifiManager.setAPCallback(configModeCallback);

  //fetches ssid and pass and tries to connect
  if (!wifiManager.autoConnect()) {
    ESP.reset();
    delay(1000);
  }

  //if you get here you have connected to the WiFi
  ticker.detach();
  //keep LED on
  digitalWrite(BUILTIN_LED, LOW);

   
  server.on("/", [](){
    server.send(200, "text/html", webPage1 + ledstatus + webPage2);
  });
  server.on("/on", [](){
    ledstatus=1;
    server.send(200, "text/html", webPage1 + ledstatus + webPage2);
    digitalWrite(gpio13Led, HIGH);
    digitalWrite(gpio14Led, LOW);
    digitalWrite(gpio12Relay, HIGH);
    delay(1000);
  });
  server.on("/off", [](){
    ledstatus=0;
    server.send(200, "text/html", webPage1 + ledstatus + webPage2);
    digitalWrite(gpio13Led, HIGH);
    digitalWrite(gpio14Led, HIGH);
    digitalWrite(gpio12Relay, LOW);
    delay(1000); 
  });
  server.begin();  
}
 
void loop(void){
  server.handleClient();
} 


